<template>
    <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <div class="search-container">
            <el-form ref="form" :model="searchForm" label-width="auto" style="width: 100%">
                <el-row :gutter="5">
                    <el-col :span="5">
                        <el-form-item label="填报日期">
                            <el-date-picker style="width: 100%;" value-format="yyyy-MM-dd"
                                    v-model="searchForm['news_date_']" type="date" placeholder="选择填报日期">
                                </el-date-picker>
                        </el-form-item>
                    </el-col>
                    <el-col :span="8">
                        <el-form-item label="新闻内容" style="width: 100%;">
                            <el-input style="width: 100%;" placeholder="请输入新闻内容" v-model="searchForm[`content_`]"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch(1)">
                            {{ this.$t('common.search') }}
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col :span="24" class="table-container" ref="contentPanel">
                <div style="margin-bottom: 10px" ref="btnPanel">
                    <el-button icon="el-icon-plus" type="primary" @click="addNew">添加</el-button>
                </div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table stripe size="mini" v-loading="tableLoading" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{ width: '100%' }"
                        @selection-change="handleSelectionChange">
                        <el-table-column type="index" width="100" label="序号" align="center">
                        </el-table-column>
                        <el-table-column prop="appName" width="180" align="center" label="填报日期">
                            <template v-slot="{ row }">
                                <el-date-picker v-if="row.isEdit" style="width: 100%;" value-format="yyyy-MM-dd"
                                    v-model="row.newsDate" type="date" placeholder="选择日期">
                                </el-date-picker>
                                <template v-else>
                                    {{ row.newsDate }}
                                </template>
                            </template>
                        </el-table-column>
                        <el-table-column prop="fieldGroup" show-overflow-tooltip min-width="180" align="left">
                            <template #header>
                                <div style="text-align: center;">新闻内容</div>
                            </template>
                            <template v-slot="{ row }">
                                <el-input v-if="row.isEdit" type="textarea" v-model="row.content"
                                    :autosize="{ minRows: 2, maxRows: 4 }"></el-input>
                                <template v-else>
                                    {{ row.content }}
                                </template>
                            </template>
                        </el-table-column>
                        <el-table-column show-overflow-tooltip width="180" align="center" fixed="right" label="操作">
                            <template v-slot="{ row, $index }">
                                <template>
                                    <span>
                                        <el-link type="primary" v-if="row.isEdit" :underline="false" class="cloumn-btn"
                                            @click="saveAddOrUpdateNew(row)">
                                            保存
                                        </el-link>
                                        <el-link type="primary" :underline="false" v-else class="cloumn-btn"
                                            @click="clickEdit(row)">
                                            编辑
                                        </el-link>
                                        <el-link type="danger" :underline="false" class="cloumn-btn withdraw"
                                            @click="handleDelete(row, $index)">
                                            删除
                                        </el-link>
                                    </span>
                                </template>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import apiList from '@/api/digitalApi/appApi'
const portal = window.context.portal
export default {
    name: 'NewsManagement',
    components: {
        pagination
    },
    mixins: [TableMixin],
    data() {
        return {
            tableMaxHeight: 400,
            loading: false,
            tableLoading: false,
            searchForm: {
            }, // 顶部搜索对象
            markLoading: false,
            tableData: [],
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                querys: [],
            },
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            deleteIds: '', // 是否选中列表解锁删除按钮

        }
    },
    created() {
        this.getData(this.params)
    },
    methods: {
        addNew() {
            this.tableData.unshift({ isEdit: true })
            this.pageResult.total = this.tableData.length
        },
        saveAddOrUpdateNew(row) {
            let { newsDate, content } = row
            if (!newsDate || !content) {
                if (!newsDate) {
                    this.$message.error('请选择填报时间')
                } else if (!content) {
                    this.$message.error('请填写新闻内容')
                }
            } else {
                let msg = row.id ? '保存修改' : '保存'
                this.$confirm(`确认${msg}吗？`, this.$t('common.tips'), {
                    confirmButtonText: this.$t('common.confirm'),
                    cancelButtonText: this.$t('common.cancel'),
                    type: 'error'
                }).then(() => {
                    this.tableLoading = true
                    let API = row.id ? 'updateNewsData' : 'saveNewsData'
                    apiList[API](row, res => {
                        if (res.state) {
                            this.$message.success(`${msg}成功`)
                            this.getData(this.params)
                        }
                    })
                })

            }
        },
        clickEdit(row) {
            row.isEdit = true
        },
        getData(data) {
            this.tableLoading = true
            apiList.getNewsData(data, res => {
                if (res) {
                    this.pageResult.total = res.total
                    this.tableLoading = false
                    this.tableData = res.rows
                    this.tableData.forEach(item => {
                        this.$set(item, 'isEdit', false)
                    })
                }
            })
        },
        handleSearch(page) {
            this.tableLoading = true
            let data = JSON.parse(JSON.stringify(this.params))
            let obj = JSON.parse(JSON.stringify(this.searchForm))
            let querys = []
            for (let i in obj) {
                if (obj[i]) {
                    querys.push({
                        group: 'main',
                        operation:
                            i == 'content_' ? 'LIKE' : 'EQUAL',
                        parentGroup: '',
                        property: i,
                        relation: 'AND',
                        value: obj[i]
                    })
                }
            }
            data.querys = querys
            data.pageBean.page = page
            this.pageResult.page = page
            apiList.getNewsData(data, res => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
                this.tableData.forEach(item => {
                    this.$set(item, 'isEdit', false)
                })
            })
        },
        handleCurrentChange(page) {
            this.params.pageBean = { ...this.params.pageBean, page }
            this.handleSearch(page)
        },
        handleSizeChange(pageSize) {
            this.params.pageBean = { ...this.params.pageBean, pageSize }
            this.handleSearch(1)
        },
        //获取删除数据id集合
        handleSelectionChange(val) {
            let arr = val.map(item => item.id)
            this.deleteIds = arr.join(',')
        },
        //删除
        handleDelete(row, index) {
            this.$confirm('确认删除吗？', this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'error'
            }).then(() => {
                if (!row.id) {
                    this.tableData.splice(index, 1)
                } else {
                    this.tableLoading = true
                    apiList.deleteNewById(row.id, res => {
                        if (res.state) {
                            this.handleSearch(1)
                            this.$message.success('删除成功')
                        } else {
                            this.tableLoading = false
                        }
                    })
                }
            })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-dialog__body {
    height: 65vh;
}

@import '~@/assets/css/element-variables.scss';

.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    /deep/ i,
    span {
        font-size: 16px;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}

.del-btn {
    font-weight: bold;
    margin-left: 10px;
    color: $--color-danger;
    cursor: pointer;
}

/deep/ .el-collapse-item__content {
    padding-bottom: 5px;
}

.fs-input {
    /deep/ .el-input__inner {
        height: 29px;
        line-height: 18px;
        text-align: center;
    }
}

.upload_file {
    opacity: 1;
    height: 100%;
    pointer-events: auto;
    // transition: all 0.3s;
}

.upload_file_none {
    opacity: 0;
    height: 0;
    pointer-events: none;
    // transition: all 0.3s;
}

/deep/ .el-upload--picture-card {
    display: block;
    border: none;
    width: 100%;
    height: 70px;
    line-height: 70px;
    text-align: left;
}

/deep/.el-upload-list--picture-card .el-upload-list__item {
    width: 100px;
    height: 70px;
}

/deep/ .upload-demo {
    display: flex;
    flex-direction: column-reverse;
    pointer-events: auto;

    > {
        flex: 1;
    }
}

/deep/ .btn-show {
    .el-upload--picture-card {
        height: 0 !important;
        width: 0;
        opacity: 0;
        pointer-events: none;
    }
}

/deep/.el-descriptions__header {
    margin: 15px 0 0 0;

    .el-descriptions__title {
        font-weight: normal;
    }
}

.file-item {
    display: flex;
    justify-content: space-between;
    width: 100%;
    padding: 5px 3px 5px;
    padding-right: 5px;
    border-radius: 2px;

    a {
        margin-right: 8px;
        user-select: none;
    }
}

.file-item:hover {
    background-color: #f5f5f5;
}

/deep/.el-input__inner::-webkit-outer-spin-button,
/deep/.el-input__inner::-webkit-inner-spin-button {
    -webkit-appearance: none;
}

.satisfaction {
    /deep/.el-table__row {
        .el-table__cell {
            .cell {
                height: 100% !important;
                line-height: 50px !important;
            }
        }
    }
}

/deep/ .el-table th.el-table__cell>.cell {
    white-space: pre;
}

// 导入居中
.import-demo {
    text-align: center;
}
</style>
